==> haskell-ixset-typed-0.3.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-EeMB1EkgK7xEwxuonYLblE
key: ixset-typed-0.3.1-EeMB1EkgK7xEwxuonYLblE
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: 873ed7cb5b54e1f9e6ed531341f5e4dc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-EeMB1EkgK7xEwxuonYLblE
depends:
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3.2-EiqtFdUFw7p6NJo2WzLmyS
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.3.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-5RO7E7ePKmT6v8zFAh9BRu
key: ixset-typed-0.3.1-5RO7E7ePKmT6v8zFAh9BRu
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: fe4ebd89e1de104c6e564fab4a4bd37a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/ixset-typed-0.3.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-5RO7E7ePKmT6v8zFAh9BRu
depends:
    base-4.9.1.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3.2-5SREq489x6g9JqiCFSVfmJ
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
